import logging
import os
import platform
import subprocess


class RemoteCommand:

    def __init__(self):
        self.work_dir = os.path.dirname(os.path.abspath(__file__))
        self.script_folder = 'au3_scripts'

    def accept_certificate(self):
        logging.debug(f'running from {self.work_dir}')
        cmd = os.path.join(f'{self.script_folder}', 'accept_certificate.exe')
        try:
            RemoteCommand._run_command(cmd)
            return True
        except FileNotFoundError as e:
            logging.error(e)
            return False

    def test_script_folder(self):
        logging.debug(f'running from {self.work_dir}')
        cmd = os.path.join(f'{self.script_folder}', 'test.txt')
        if platform.system().lower() == 'linux':
            try:
                RemoteCommand._run_command(f'cat {cmd}')
                return True
            except FileNotFoundError as e:
                logging.error(e)
                return False
        else:
            logging.error('not running on linux, can\'t run cat')
            return False

    @staticmethod
    def _run_command(cmd):
        cmd = cmd.split()
        logging.debug('command in list format:{}'.format(cmd))
        output = subprocess.check_output(cmd, shell=False)
        logging.info(f'response is {output} of type {type(output)}')






class RemoteControlException(Exception):
    def __init__(self, msg, original_exception=None):

        if original_exception:
            my_msg = '{}: {}'.format(msg, original_exception)
        else:
            my_msg = msg
        super(RemoteControlException, self).__init__(my_msg)
        self.original_exception = original_exception



import argparse
import logging
import os
import sys
from logging import handlers
from visualgc_remote_control.enterprise import RemoteControlException
from visualgc_remote_control.remote_control_app import RemoteControlApp
from visualgc_remote_control.remote_commands import RemoteCommand

# VERSION = '0.0.1'  # Initial version
VERSION = '0.0.2'  # Redo imports


class VisualgcRemoteControl:

    def __init__(self):
        self.current_dir = os.path.dirname(os.path.abspath(__file__))
        self.work_dir = os.path.join(self.current_dir, 'tmp')
        msg = f'running on Python {sys.version_info.major}.{sys.version_info.minor}.{sys.version_info.micro}-{sys.version_info.releaselevel}'
        logging.debug(msg)

    @staticmethod
    def str2bool(v):
        if isinstance(v, bool):
            return v
        if v.lower() in ('yes', 'true', 't', 'y', '1'):
            return True
        elif v.lower() in ('no', 'false', 'f', 'n', '0'):
            return False
        else:
            raise argparse.ArgumentTypeError('Boolean new_value expected, got {}'.format(v))

    @staticmethod
    def main():
        my_log = logging.getLogger()
        my_log.setLevel(logging.DEBUG)
        my_fmt = logging.Formatter("%(asctime)s - %(name)s - %(levelname)s - %(message)s")
        my_ch = logging.StreamHandler(sys.stdout)
        my_ch.setFormatter(my_fmt)
        my_log.addHandler(my_ch)
        my_fh = handlers.RotatingFileHandler('visualgc_remote_control.log', maxBytes=(1048576 * 5), backupCount=7)
        my_fh.setFormatter(my_fmt)
        my_log.addHandler(my_fh)

        logging.info(f'start...')
        logging.info(f'VisualGC remote control {VERSION}')
        p = VisualgcRemoteControl()
        parser = argparse.ArgumentParser(prog='visualgc_remote_control.py')

        subparsers = parser.add_subparsers()
        subparsers.required = True
        subparsers.dest = 'command'
        subparser = subparsers.add_parser("START_SERVER", help="Accept certificate from the controller")
        subparser = subparsers.add_parser("ACCEPT_CERTIFICATE", help="Accept certificate from the controller")
        subparsers.add_parser("VERSION", help="Print version")
        ret = 0

        try:
            args = parser.parse_args()
            if  args.command == 'START_SERVER':
                p.start_server()
            elif args.command == 'ACCEPT_CERTIFICATE':
                p.accept_certificate()
            elif args.command == 'VERSION':
                logging.info('version={0}'.format(VERSION))
            else:
                parser.print_help()
            logging.info('... all done')

        except RemoteControlException as e:
            logging.error(e)
            logging.info('... exiting with error')

    def accept_certificate(self):
        # run autoit executable
        RemoteCommand.accept_certificate()

    def start_server(self):
        my_server = RemoteControlApp.run()


if __name__ == "__main__":
    VisualgcRemoteControl.main()






import logging

from flask import Flask, Response, render_template
from visualgc_remote_control.remote_commands import RemoteCommand

global_command_facade = RemoteCommand()


class RemoteControlApp:

    @staticmethod
    def run():
        app = Flask(__name__)
        app.add_url_rule('/', view_func=RemoteControlApp.index, methods=['GET'])
        app.add_url_rule('/accept_certificate', view_func=RemoteControlApp.accept_certificate, methods=['GET'])
        app.add_url_rule('/linux_test', view_func=RemoteControlApp.test_script_folder, methods=['GET'])
        # app.register_error_handler(404, RemoteControlApp.page_not_found)
        logging.getLogger('werkzeug').disabled = True
        debug_mode = True
        app.run(host="0.0.0.0", debug=debug_mode)

    @staticmethod
    def index():
        # http://localhost:5000/
        return "<h1>This is my indexpage</h1>"

    @staticmethod
    def accept_certificate():
        # return Response('certificate found', status=200, headers={})
        if global_command_facade.accept_certificate():
            return Response('accept certificate OK', status=200, headers={})
        else:
            msg = f'unable to run command accept_certificate'
            logging.error(msg)
            return Response(msg, status=500, headers={})

    @staticmethod
    def test_script_folder():
        # return Response('certificate found', status=200, headers={})
        if global_command_facade.test_script_folder():
            return Response('Test OK', status=200, headers={})
        else:
            msg = f'unable to run Test'
            logging.error(msg)
            return Response(msg, status=500, headers={})

    @staticmethod
    def page_not_found(e):
        # note that we set the 404 status explicitly
        return render_template('404.html'), 404










from setuptools import setup

setup(
    name="visualgc-remote-control",
    license='Apache v2',
    packages=["visualgc_remote_control",
              "visualgc_remote_control.au3_scripts"],  # this must be the same as the name above
    version="0.0.2",
    description="visualgc-remote-control",
    author="Luis Coelho",
    author_email="luis.coelho.720813@gmail.com",
    url='https://luism.co',
    keywords=["VisualGC", "Configuration", "REST"],  # arbitrary keywords
    data_files=[
        ("/etc/schindler", ["visualgc-remote-control.yaml"]),
    ],
    install_requires=[
        'Flask>=2.2.2',

    ],
    entry_points={
        "console_scripts": ["visualgc-remote-control=visualgc_remote_control.visualgc_remote_control:VisualgcRemoteControl.main"],
    },
)
